@@ -1,4 +1,4 @@
-"cart2clock" <-
+`cart2clock` <-
 function(x, y = NULL, circle)
   ## Author: Rene Locher
   ## Version: 2005-10-05
@@ -13,5 +13,5 @@ function(x, y = NULL, circle)
   y <- xy$y
   phi <-(atan(x/y)/2/pi*circle + ifelse(y>0,circle,1.5*circle))%%circle
   return(data.frame(rho=sqrt(x*x+y*y),phi=phi))
-}
+} ## cart2clock
 
