@@ -3,15 +3,13 @@ function(colramp = IDPcolorRamp,
                         ncol = NULL, cex.axis = par("cex.axis"),
                         border = FALSE, mar = c(0,0,0,3), las = 1, ...)
   ## internal functions for ipairs and ilagplot
-  ## Version  2009-03-10
+  ## Version  2009-03-26
 {
 
       ##-------------------
       ## drawing legend
       ## calculate colcut only when common ncol is defined
       if(is.null(ncol)) {
-          ## warning(c("Separate color coding for each image\n"),
-          ##         call. = FALSE)
           border <- FALSE
           mycol <- c(par("bg"),colramp(100))
       }else {
@@ -20,8 +18,7 @@ function(colramp = IDPcolorRamp,
       }
 
       lev <- 0:length(mycol)
-      par(mar=c(mar[1:3],cex.axis*mar[4]), las=las,
-          cex.axis=cex.axis, ...)
+      par(mar=mar, las=las, cex.axis=cex.axis, ...)
       plot.new()
       plot.window(xlim=c(0, 1), ylim=range(lev,na.rm=TRUE),
                   xaxs="i", yaxs="i")
