@@ -1,19 +1,19 @@
 `plot.onepage` <-
 function(y1, y2, names1, names2,
-                         startP, upf, fpp, overlap,
-                         x.ann, dx.ann, dx.tick, ny.ann,cex.ann,
-                         xlab, y1lab, y2lab, col.y1, col.y2,
-                         y2.lab, cex.lab,
-                         y1lim, y2lim, aty1, aty2,
-                         lty1, lty2, lwd1, lwd2, col1, col2,
-                         leg, y1nam.leg, y2nam.leg,
-                         ncol.leg, cex.leg=1.5,
-                         h1, h2, col.h1, col.h2,
-                         main, cex.main, mgp, mar, oma, cex, type){
-  ## internal function
-  ## Author:  Rene Locher
-  ## Version: 2007-10-02
-  
+           startP, upf, fpp, overlap,
+           x.ann, dx.ann, dx.tick, ny.ann,cex.ann,
+           xlab, y1lab, y2lab, col.y1, col.y2,
+           y2.lab, cex.lab,
+           y1lim, y2lim, aty1, aty2,
+           lty1, lty2, lwd1, lwd2, col1, col2,
+           leg, y1nam.leg, y2nam.leg,
+           ncol.leg, cex.leg=1.5,
+           h1, h2, col.h1, col.h2,
+           main, cex.main, mgp, mar, oma, cex, type){
+    ## internal function
+    ## Author:  Rene Locher
+    ## Version: 2008-06-30
+    
   options(warn=-1)
   on.exit(options(warn=0), add=TRUE)
 
@@ -42,8 +42,8 @@ function(y1, y2, names1, names2,
         stop(paste("\nUndefined error:\n",
                    geterrmessage(),sep=""), call. = FALSE)
       }
-      
-      if (!is.null(h1)) abline(h=h1, col=col.h1)
+
+      if (!is.null(h1)) abline(h=h1, col=col.h1, xpd=FALSE)
       
       if (!is.null(y2)) {
         st2 <- start(y2)
@@ -55,7 +55,7 @@ function(y1, y2, names1, names2,
         for (ii in 1:ncol(y2))
           lines(window(y2[,ii],start=st2,end=ee2),col=col2[ii],
                 lty=lty2[ii], lwd=lwd2, type=type)
-        if (!is.null(h2)) abline(h=h2, col=col.h2)
+        if (!is.null(h2)) abline(h=h2, col=col.h2, xpd=FALSE)
        }
       
       ## Make sure that units labeled correctly
